%% Library of examples

fprintf('\n ============== EXAMPLE LIBRARY ============== \n');
fprintf(['\n - Example mode is: ',exampleMode,'\n']);

switch exampleMode
    case 'LTI'
        %% Definition of nominal plant
        m1 = 1; m2 = 0.5; k = 1; % known system parameters
        c = 2; % Nominal value of uncertain real parameter
        
        % Definition of nominal plant
        A = [0, 0, 1, 0;...
            0, 0, 0, 1;...
            -2*k/m1, k/m1, -c/m1, c/m1;...
            k/m2, -k/m2, c/m2, -c/m2];
        B = [zeros(2,4); -1.5, 1.5, 1, 0; 3, -3, 0, 0];
        C = [0, 0, 1, 0; 0, 0, 0, 1; 1, 0, 0, 0; 0, 1, 0, 0];
        D = [zeros(2,4); 0, 0, 0, 1; zeros(1,4)];
        P = ss(A,B,C,D);
        C3 = [0, 1, 0, 0]; % output to be estimated
        
        % Definition of uncertain objects and plant
        delta = ureal('delta',0); % unit norm-bounded ureal
        DELTA = delta*eye(2); % uncertain matrix
        Punc = NaN; % uncertain SS object is undefined

    case 'LPV'
        %% Definition of nominal plant
        m1 = 1; m2 = 0.5; k = 1; % known system parameters
        c = 2; % Nominal value of uncertain real parameter
        
        % Parameter dependence
        rho = pgrid('rho',[0,pi/6,pi/3]); % define parameter grid
        % rho = tvreal('rho',[-pi/6,pi/6]); % define time-varying real para
        c1 = abs(sin(rho)); % define parameter-dependent damping coefficient
        
        % Definition of uncertain parameter-varying system
        A = [0, 0, 1, 0;...
            0, 0, 0, 1;...
            -2*k/m1, k/m1, -c/m1, c/m1;...
            k/m2, -k/m2, c/m2, -c/m2];
        Alpv = [zeros(2,4); 0, 0, -c1/m1, 0; zeros(1,4)];
        Aup = A + Alpv;
        B = [zeros(2,4); -1.5, 1.5, 1, 0; 3, -3, 0, 0];
        C = [0, 0, 1, 0; 0, 0, 0, 1; 1, 0, 0, 0; 0, 1, 0, 0];
        D = [zeros(2,4); 0, 0, 0, 1; zeros(1,4)];
        P = pss(Aup,B,C,D);
        C3 = [0, 1, 0, 0]; % output to be estimated
        
        % Definition of uncertain objects and plant
        delta = ureal('delta',0); % unit norm-bounded ureal
        DELTA = delta*eye(2); % uncertain matrix
        Punc = NaN; % uncertain SS object is undefined
end
