function [GICT,Gnom] = robfiltana(DELTA,P,PICT,F)
%ROBFILTANA conducts analysis of the filter synthesized by robfiltsyn.

%% Extract matrix sizes
% n = length(P.StateName);
% nw = length(P.InputGroup.Uncertain);
% m = length(P.InputGroup.Disturbance);
% nv = length(P.OutputGroup.Uncertain);
% p = length(P.OutputGroup.Measurement);
nz = length(P.OutputGroup.ToBeEstimated);

%% Plant-filter interconnection
% Sum block for estimation error
if nz == 1
    sumJnc = ss(sumblk('e(1) = zhat(1) - z(1)'));
else
    sumJnc = ss(sumblk('e = zhat - z',nz)); % automatic vectorization expected
end
set(sumJnc,'InputGroup',struct('OutputEstimate',1:nz,'ToBeEstimated',nz+1:nz+nz),...
    'OutputGroup',struct('EstimationError',1:length(sumJnc.OutputName)));

% Interconnection (Gnom)
Gnom = connect(lft(DELTA.NominalValue,P),F,sumJnc,'d','e'); % Gnom = lft(0,G);

% Peak induced L2 norm of Gnom
if isa(P,'ss') || isa(P,'tf') || isa(P,'zpk')
    Gnom_indL2 = norm(Gnom,inf);
elseif isa(P,'pss') || isa(P,'plftss') || isa(P,'upss')
    Gnom_indL2 = lpvnorm(Gnom,'L2');
else
    warning(['Unknown input class: ',class(P),'.']);
end
fprintf('\n\n - The peak induced L2 norm of lft(0,G) is %4.2f.\n',Gnom_indL2);

%% Plant-filter interconnection with psi filters
GICT = connect(PICT,F,sumJnc,{'w';'d'},...
    [PICT.OutputName([PICT.OutputGroup.Uncertainv,PICT.OutputGroup.Uncertainw]);...
    'e']);

end
