function userGuide(varargin)
%USERGUIDE Displays an index of function and variable names.
% To display variable names, type userGuide('variables')
% To display function names, type userGuide('functions')
% To display both, type userGuide('variables','functions')

%% Error protection
if ~sum([strcmpi(varargin,'variables'),strcmpi(varargin,'functions')])
    error('Invalid input argument.');
end

%% Variable names
if sum(strcmpi(varargin,'variables'))
    fprintf('\n -------------- Variables -------------- \n');
    fprintf(['\n - I/O groups are: "Uncertain", "Disturbance", "Measurement",\n',...
        '   "ToBeEstimated", "OutputEstimate", and derived names.\n']);
    fprintf('\n - Type the following variable names to interact with the model.\n');
    fprintf('\n \t Punc \t\t Uncertain plant, Punc = lft(DELTA,P).\n');
    fprintf('\n \t P \t\t\t Nominal plant.\n');
    fprintf('\n \t PSIICT \t State-space interconnection of all IQC filters.\n');
    fprintf('\n \t PSICOLL \t Cell array of all IQC filters.\n');
    fprintf('\n \t PICT \t\t State-space interconnection of P and PSIICT.\n');
    fprintf('\n \t F \t\t\t Synthesized filter.\n');
    fprintf(['\n \t Mm \t\t Single structured M-matrix resulting from SDP.\n',...
        ' \t    \t\t (Zeros returned when IQC mode is "MultipleLm".)\n']);
    fprintf(['\n \t lm \t\t Multiple IQC weights resulting from SDP.\n',...
        ' \t    \t\t (Zeros returned when IQC mode is "SingleM".)\n']);
    fprintf(['\n \t Plyap \t\t Lyapunov matrix for GICT; size (2nx2n).\n',...
        ' \t\t    \t - Plyap is not necessarily positive definite.\n',...
        ' \t\t    \t - Plyap > 0 when specific types of IQC factorizations are used.\n']);
end

%% Function names
if sum(strcmpi(varargin,'functions'))
    fprintf('\n -------------- Functions -------------- \n');
    fprintf('\n - Type help <space> the following function names.\n');
    fprintf('\n \t main \t\t\t\t Main script to be executed.\n');
    fprintf('\n \t exampleLibrary \t Library of examples.\n');
    fprintf('\n \t IOgroup \t\t\t Groups inputs and outputs of the nominal plant.\n');
    fprintf('\n \t psiFilterICT \t\t Connects nominal plant and PSI filters.\n');
    fprintf('\n \t wcgAnalysisEngine \t Engine that chooses the right wcgainAnalysis function.\n');
    fprintf('\n \t wcgAnalysis \t\t Worst-case gain IQC analysis of LTI uncertain plants.\n');
    fprintf('\n \t wcgLPVAnalysis \t Worst-case gain IQC analysis of LPV uncertain plants.\n');
    fprintf('\n \t robfiltsynEngine \t Engine that chooses the right robfiltsyn function.\n');
    fprintf('\n \t robfiltsyn \t\t Robust estimator synthesis for uncertain LTI plants.\n');
    fprintf('\n \t robfiltLPVsyn \t\t Robust estimator synthesis for uncertain LPV plants.\n');
    fprintf(['\n \t robfiltana \t\t Post-synthesis analysis of plant-filter\n',...
             ' \t\t\t\t\t\t interconnection.\n']);
end

end
